ContractERC1155SupplyBurnable class
Dart Class for both ContractERC1155Supply and ContractERC1155Burnable combined.
- Inheritance
-
- Object
- ContractERC1155
- ContractERC1155SupplyBurnable
- Mixed-in types
Constructors
- ContractERC1155SupplyBurnable(String address, dynamic providerOrSigner, [dynamic abi])
-
Instantiate ERC1155 Contract using default abi if
abiis notnull.
Properties
Methods
-
approvalForAllEvents(
[List? args, dynamic startBlock, dynamic endBlock]) → Future< List< Event> > -
Log of
ApprovalForAllevents.inherited -
balanceOf(
String address, int id) → Future< BigInt> -
Returns the amount of tokens
idowned byaddressinherited -
balanceOfBatch(
List< String> addresses, List<int> ids) → Future<List< BigInt> > -
Returns the amount of tokens
idsowned byaddressesinherited -
balanceOfBatchSingleAddress(
String address, List< int> ids) → Future<List< BigInt> > -
Returns the amount of tokens
idsowned byaddressinherited -
burn(
String address, int id, BigInt value) → Future< TransactionResponse> -
inherited
-
burnBatch(
String address, List< int> ids, List<BigInt> values) → Future<TransactionResponse> -
inherited
-
connect(
dynamic providerOrSigner) → void -
Connect current contract with
providerOrSignerinherited -
exists(
int id) → Future< bool> -
Indicates weither any token exist with a given
id, or not.inherited -
isApprovedForAll(
String owner, String spender) → Future< bool> -
Returns
trueifspenderis approved to transferownertokensinherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onApprovalForAll(
void callback(String account, String operator, Event event)) → void -
Emitted when
accountgrants or revokes permission tooperatorto transfer their tokens, according toapproved.inherited -
onTransferBatch(
void callback(String operator, String from, String to, Event event)) → void -
Equivalent to multiple
TransferSingleevents, whereoperator,fromandtoare the same for all transfers.inherited -
onTransferSingle(
void callback(String operator, String from, String to, Event event)) → void -
Emitted when
valuetokens of token typeidare transferred fromfromtotobyoperator.inherited -
safeBatchTransferFrom(
String from, String to, List< int> id, List<BigInt> amount, String data) → Future<TransactionResponse> -
Batched version of safeTransferFrom.
inherited
-
safeTransferFrom(
String from, String to, int id, BigInt amount, String data) → Future< TransactionResponse> -
Transfers
amounttokens of token typeidfromfromtoto.inherited -
setApprovedForAll(
String spender, bool approved) → Future< TransactionResponse> -
Grants or revokes permission to
spenderto transfer the caller's tokens, according toapproved,inherited -
toString(
) → String -
A string representation of this object.
inherited
-
totalSupply(
int id) → Future< BigInt> -
Total amount of tokens in with a given
id.inherited -
transferBatchEvents(
[List? args, dynamic startBlock, dynamic endBlock]) → Future< List< Event> > -
Log of
TransferBatchevents.inherited -
transferSingleEvents(
[List? args, dynamic startBlock, dynamic endBlock]) → Future< List< Event> > -
Log of
TransferSingleevents.inherited -
uri(
int id) → FutureOr< String> -
Returns the URI for token type
id.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited